@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2007-2009 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2012 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -1123,6 +1123,18 @@ void SelectJob::aboutToBeDequeued(ThreadWeaver::WeaverInterface*)
     m_dequeued=true;
 }
 
+
+inline QMap<uint,qlonglong> invertMap(const QMap<qlonglong,uint>& source)
+{
+    //uses the fact that map has its keys always sorted
+    QMap<uint,qlonglong> sortingMap;
+    for(QMap<qlonglong,uint>::const_iterator i=source.constBegin(); i!=source.constEnd(); ++i)
+    {
+        sortingMap.insertMulti(i.value(), i.key());
+    }
+    return sortingMap;
+}
+
 //returns true if seen translation with >85%
 bool SelectJob::doSelect(QSqlDatabase& db,
                          QStringList& words,
@@ -1131,12 +1143,12 @@ bool SelectJob::doSelect(QSqlDatabase& db,
 {
     bool qpsql=(db.driverName()=="QPSQL");
     QMap<qlonglong,uint> occurencies;
-    QList<qlonglong> idsForWord;
+    QVector<qlonglong> idsForWord;
 
     QSqlQuery queryWords(db);
     //TODO ??? not sure. make another loop before to create QList< QList<qlonglong> > then reorder it by size
-    const char* const queryC[]={"SELECT ids_long FROM words WHERE word='%1'",
-                               "SELECT ids_short FROM words WHERE word='%1'"};
+    static const QString queryC[]={QString("SELECT ids_long FROM words WHERE word='%1'"),
+                               QString("SELECT ids_short FROM words WHERE word='%1'")};
     QString queryString=queryC[isShort];
 
     //for each word...
@@ -1147,8 +1159,6 @@ bool SelectJob::doSelect(QSqlDatabase& db,
         if (!(   !idsForWord.isEmpty() && words.at(o)==words.at(o+1)   ))
         {
             idsForWord.clear();
-//             queryWords.bindValue(0, words.at(o));
-//             if (KDE_ISUNLIKELY(!queryWords.exec()))
             queryWords.exec(queryString.arg(words.at(o)));
             if (KDE_ISUNLIKELY(!queryWords.exec(queryString.arg(words.at(o)))))
                 kWarning(TM_AREA) <<"select error: " <<queryWords.lastError().text() << endl;
@@ -1160,6 +1170,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
 
                 QList<QByteArray> ids(arr.split(' '));
                 int p=ids.size();
+                idsForWord.reserve(p);
                 while (--p>=0)
                     idsForWord.append(ids.at(p).toLongLong(/*bool ok*/0,36));
             }
@@ -1170,19 +1181,12 @@ bool SelectJob::doSelect(QSqlDatabase& db,
             }
         }
 
-        int i=idsForWord.size();
         //kWarning(TM_AREA) <<"SelectJob: idsForWord.size() "<<idsForWord.size()<<endl;
 
         //iterate over ids: this computes hit count for each id
-        while (--i>=0)
-        {
-            uint a=1;
-            if (occurencies.contains(idsForWord.at(i)))
-                a+=occurencies.value(idsForWord.at(i));
-            occurencies.insert(idsForWord.at(i),a);
-        }
+        for(QVector<qlonglong>::const_iterator i=idsForWord.constBegin(); i!=idsForWord.constEnd(); i++)
+            occurencies[*i]++; //0 is default value
     }
-    idsForWord.clear();
 
     //accels are removed
     TMConfig c=getConfig(db);
@@ -1199,30 +1203,31 @@ bool SelectJob::doSelect(QSqlDatabase& db,
     static QRegExp addPart("<KBABELADD>*</KBABELADD>", Qt::CaseSensitive, QRegExp::Wildcard);
     delPart.setMinimal(true);
     addPart.setMinimal(true);
-    
-    QList<uint> concordanceLevels( ( occurencies.values().toSet() ).toList() );
-    qSort(concordanceLevels); //we start from entries with higher word-concordance level
-    int i=concordanceLevels.size();
+
+    //QList<uint> concordanceLevels=sortedUniqueValues(occurencies); //we start from entries with higher word-concordance level
+    QMap<uint,qlonglong> concordanceLevelToIds=invertMap(occurencies);
+    if (concordanceLevelToIds.isEmpty())
+        return false;
     bool seen85=false;
-    int limit=21;
-    while ((--limit>=0)&&(--i>=0))
+    int limit=200;
+    QMap<uint,qlonglong>::const_iterator clit=concordanceLevelToIds.constEnd();
+    if (concordanceLevelToIds.size()) --clit;
+    if (concordanceLevelToIds.size()) while (--limit>=0)
     {
-        //for every concordance level
-
-
         if (KDE_ISUNLIKELY( m_dequeued ))
             break;
 
-        QList<qlonglong> ids(occurencies.keys(concordanceLevels.at(i)));
-
-        int j=qMin(ids.size(),100);//hard limit
-        //kWarning(TM_AREA) <<"ScanJob: doin "<<concordanceLevels.at(i)<<" limit "<<j;
-        limit-=j;
-
+        //for every concordance level
+        qlonglong level=clit.key();
         QString joined;
-        while(--j>0)
-            joined+=QString("%1,").arg(ids.at(j));
-        joined+=QString::number(ids.at(j));
+        while(level==clit.key())
+        {
+            joined+=QString::number(clit.value())+',';
+            if (clit==concordanceLevelToIds.constBegin() || --limit<0)
+                break;
+            --clit;
+        }
+        joined.chop(1);
 
         //get records containing current word
         QSqlQuery queryFetch("SELECT id, source, source_accel, source_markup FROM source_strings WHERE "
@@ -1230,7 +1235,6 @@ bool SelectJob::doSelect(QSqlDatabase& db,
         TMEntry e;
         while (queryFetch.next())
         {
-            ++j;
             e.id=queryFetch.value(0).toLongLong();
             if (queryFetch.value(3).toByteArray().size())
                 qDebug()<<"BA"<<queryFetch.value(3).toByteArray();
@@ -1351,7 +1355,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                                 ,db); //ORDER BY tm_main.id ?
             queryRest.exec();
             //qDebug()<<"main select error"<<queryRest.lastError().text();
-            QList<TMEntry> tempList;//to eliminate same targets from different files
+            QMap<TMEntry,bool> sortedEntryList;//to eliminate same targets from different files
             while (queryRest.next())
             {
                 e.id=queryRest.value(0).toLongLong();
@@ -1401,29 +1405,32 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                     e.score+=33;
 //END exact match score++
                 //kWarning(TM_AREA)<<"appending"<<e.target;
-                tempList.append(e);
+                sortedEntryList.insertMulti(e, false);
             }
             queryRest.clear();
             //eliminate same targets from different files
-            qSort(tempList.begin(), tempList.end(), qGreater<TMEntry>());
             QHash<QString,int> hash;
-            int recentlyAddedCount=0;
-            foreach(const TMEntry& e, tempList)
+            int oldCount=m_entries.size();
+            QMap<TMEntry,bool>::const_iterator it=sortedEntryList.constEnd();
+            if (sortedEntryList.size()) while(true)
             {
-                if (!hash.contains(e.target.string))
-                {
-                    hash[e.target.string]=1;
+                --it;
+                const TMEntry& e=it.key();
+                int& hits=hash[e.target.string];
+                if (!hits) //0 was default value
                     m_entries.append(e);
-                    recentlyAddedCount++;
-                }
-                else
-                    hash[e.target.string]++;
+                hits++;
+                if (it==sortedEntryList.constBegin())
+                  break;
             }
-            for (int i=m_entries.size()-recentlyAddedCount;i<m_entries.size();++i)
+            for (int i=oldCount;i<m_entries.size();++i)
                 m_entries[i].hits=hash.value(m_entries.at(i).target.string);
 //END fetch rest of the data
         }
         queryFetch.clear();
+        if (clit==concordanceLevelToIds.constBegin())
+            break;
+        if (seen85) limit=qMin(limit, 100); //be more restrictive for the next concordance levels
     }
     return seen85;
 }
@@ -1508,7 +1515,7 @@ void ScanJob::run()
     m_added=0;      //stats
     m_newVersions=0;//stats
     QSqlDatabase db=QSqlDatabase::database(m_dbName);
-    initSqliteDb(db);
+    //initSqliteDb(db);
     TMConfig c=getConfig(db,true);
     QRegExp rxClean1(c.markup);rxClean1.setMinimal(true);
 
@@ -1530,24 +1537,25 @@ void ScanJob::run()
         queryBegin.exec(QString("UPDATE main SET bits=(bits|1) WHERE file=%1").arg(fileId));
         //kWarning(TM_AREA) <<"UPDATE error: " <<queryBegin.lastError().text();
 
-        for (int i=0;i<catalog.numberOfEntries();++i)
+        int numberOfEntries=catalog.numberOfEntries();
+        DocPosition pos(0);
+        for (;pos.entry<numberOfEntries;pos.entry++)
         {
             bool ok=true;
-            if (catalog.isPlural(i))
+            if (catalog.isPlural(pos.entry))
             {
-                DocPosition pos;
-                pos.entry=i;
-                for (pos.form=0;pos.form<catalog.numberOfPluralForms();++pos.form)
+                DocPosition ppos=pos;
+                for (ppos.form=0;ppos.form<catalog.numberOfPluralForms();++ppos.form)
                 {
 /*
                     QString target;
                     if ( catalog.isApproved(i) && !catalog.isUntranslated(pos))
                         target=catalog.target(pos);
 */
-                    ok=ok&&doInsertEntry(catalog.sourceWithTags(pos),
-                                          catalog.targetWithTags(pos),
-                                          catalog.context(i).first()+TM_DELIMITER+QString::number(pos.form),
-                                          catalog.isApproved(i),
+                    ok=ok&&doInsertEntry(catalog.sourceWithTags(ppos),
+                                          catalog.targetWithTags(ppos),
+                                          catalog.context(ppos).first()+TM_DELIMITER+QString::number(ppos.form),
+                                          catalog.isApproved(ppos),
                                           fileId,db,rxClean1,c.accel,priorId,priorId);
                 }
             }
@@ -1558,10 +1566,10 @@ void ScanJob::run()
                 if ( catalog.isApproved(i) && !catalog.isUntranslated(i))
                     target=catalog.target(i);
 */
-                ok=doInsertEntry(catalog.sourceWithTags(i),
-                                 catalog.targetWithTags(i),
-                                 catalog.context(i).first(),
-                                 catalog.isApproved(i),
+                ok=doInsertEntry(catalog.sourceWithTags(pos),
+                                 catalog.targetWithTags(pos),
+                                 catalog.context(pos).first(),
+                                 catalog.isApproved(pos),
                                  fileId,db,rxClean1,c.accel,priorId,priorId);
             }
             if (KDE_ISLIKELY( ok ))
@@ -1722,7 +1730,7 @@ TmxParser::TmxParser(const QString& dbName)
 
 bool TmxParser::startDocument()
 {
-    initSqliteDb(db);
+    //initSqliteDb(db);
     m_fileIds.clear();
 
     QSqlQuery queryBegin("BEGIN",db);
@@ -1885,15 +1893,14 @@ void ImportTmxJob::run()
     thread()->setPriority(QThread::IdlePriority);
     QTime a;a.start();
 
+    QFile file(m_filename);
+    if (!file.open(QFile::ReadOnly | QFile::Text))
+         return;
 
     TmxParser parser(m_dbName);
     QXmlSimpleReader reader;
     reader.setContentHandler(&parser);
 
-    QFile file(m_filename);
-    if (!file.open(QFile::ReadOnly | QFile::Text))
-         return;
-
     QXmlInputSource xmlInputSource(&file);
     if (!reader.parse(xmlInputSource))
          kWarning(TM_AREA) << "failed to load "<< m_filename;
