@@ -23,30 +23,31 @@
 #ifndef ARRAYDATAINFORMATION_H_
 #define ARRAYDATAINFORMATION_H_
 
-#include "../primitivedatatype.h" //TODO remove once primitiveArrayFromType is in subclass
-#include "../datainformation.h"
+#include "../dummydatainformation.h"
 #include "abstractarraydata.h"
 
+#include <QVariant>
+#include <QScriptValue>
+
 class DummyDataInformation;
 class AbstractArrayData;
-class ArrayDataInformation : public DataInformation
+class PrimitiveDataInformation;
+
+class ArrayDataInformation : public DataInformationWithDummyChildren
 {
     friend class PrimitiveArrayTest;
-protected:
-    explicit ArrayDataInformation(const ArrayDataInformation& d);
+    DATAINFORMATION_CLONE_DECL(ArrayDataInformation, DataInformationWithDummyChildren);
 public:
     /** creates a new array with initial length @p length.
      *  takes ownership over @p childType
      *  length should be > 0
      */
-    ArrayDataInformation(QString name, uint length, DataInformation* childType,
-            DataInformation* parent = 0);
+    ArrayDataInformation(const QString& name, uint length, DataInformation* childType,
+            DataInformation* parent = 0, const QScriptValue& lengthFuntion = QScriptValue());
     virtual ~ArrayDataInformation();
-    DATAINFORMATION_CLONE(Array)
-
 public:
     virtual QString typeName() const;
-    int length() const;
+    uint length() const;
     virtual QWidget* createEditWidget(QWidget* parent) const;
     virtual QVariant dataFromWidget(const QWidget* w) const;
     virtual void setWidgetData(QWidget* w) const;
@@ -69,39 +70,42 @@ public:
     virtual DataInformation* childAt(unsigned int idx) const;
     virtual unsigned int childCount() const;
     virtual bool canHaveChildren() const;
+    virtual QString childTypeName(uint index) const;
     virtual int indexOf(const DataInformation* const data) const;
     BitCount32 childSize(uint index) const;
 
     virtual bool isArray() const;
 
-    QScriptValue setArrayLength(int newLength, QScriptContext* context);
-    QScriptValue setArrayType(QScriptValue type, QScriptContext* context);
+    bool setArrayLength(uint newLength);
+    /** Sets the new array type
+     * @param newChildtype the new type (ownership is always taken, do not use anymore after this call!)
+     */
+    void setArrayType(DataInformation* newChildtype);
 
-    virtual QScriptValue childType() const;
-    virtual QScriptValue toScriptValue(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo);
+    QScriptValue childType() const;
+    QScriptValue lengthFunction() const;
+    void setLengthFunction(QScriptValue newFunc);
     QScriptValue childToScriptValue(uint index, QScriptEngine* engine, ScriptHandlerInfo* handlerInfo) const;
+    virtual BitCount64 childPosition(const DataInformation* child, Okteta::Address start) const;
+protected:
+    virtual QScriptClass* scriptClass(ScriptHandlerInfo* handlerInfo) const;
 private:
     /** Takes ownership of @p data ! */
     AbstractArrayData* arrayDataFromType(uint length, DataInformation* data);
-    AbstractArrayData* primitiveArrayFromType(uint length, PrimitiveDataType type);
+    AbstractArrayData* primitiveArrayFromType(uint length, PrimitiveDataInformation* type);
 protected:
-    virtual BitCount32 offset(unsigned int index) const;
-
     QScopedPointer<AbstractArrayData> mData;
+    QScriptValue mLengthFunction;
     static const uint MAX_LEN = 10000;
 };
 
-inline int ArrayDataInformation::length() const
+inline uint ArrayDataInformation::length() const
 {
-    if (Q_UNLIKELY(!mData))
-        return 0;
     return mData->length();
 }
 
 inline QString ArrayDataInformation::typeName() const
 {
-    if (Q_UNLIKELY(!mData))
-        return QString();
     return mData->typeName();
     //don't show name of child
     //return i18nc("array type then length", "%1[%2]", data->typeName(), childCount()); //TODO
@@ -109,8 +113,6 @@ inline QString ArrayDataInformation::typeName() const
 
 inline BitCount32 ArrayDataInformation::size() const
 {
-    if (Q_UNLIKELY(!mData))
-        return 0;
     return mData->size();
 }
 
@@ -121,15 +123,11 @@ inline bool ArrayDataInformation::isArray() const
 
 inline DataInformation* ArrayDataInformation::childAt(unsigned int idx) const
 {
-    if (Q_UNLIKELY(!mData))
-        return 0;
     return mData->childAt(idx);
 }
 
 inline unsigned int ArrayDataInformation::childCount() const
 {
-    if (Q_UNLIKELY(!mData))
-        return 0;
     return mData->length();
 }
 
@@ -140,44 +138,50 @@ inline bool ArrayDataInformation::canHaveChildren() const
 
 inline int ArrayDataInformation::indexOf(const DataInformation*const data) const
 {
-    if (Q_UNLIKELY(!mData))
-        return 0;
     return mData->indexOf(data);
 }
 
 inline BitCount32 ArrayDataInformation::childSize(uint index) const
 {
-    if (Q_UNLIKELY(!mData))
-        return 0;
     return mData->sizeAt(index);
 }
 
 inline Qt::ItemFlags ArrayDataInformation::childFlags(int row, int column, bool fileLoaded) const
 {
-    if (Q_UNLIKELY(!mData))
-        return 0;
     return mData->childFlags(row, column, fileLoaded);
 }
 
 inline QWidget* ArrayDataInformation::createChildEditWidget(uint index, QWidget* parent) const
 {
-    if (Q_UNLIKELY(!mData))
-        return 0;
     return mData->createChildEditWidget(index, parent);
 }
 
 inline QVariant ArrayDataInformation::dataFromChildWidget(uint index, const QWidget* w) const
 {
-    if (Q_UNLIKELY(!mData))
-        return QVariant();
     return mData->dataFromChildWidget(index, w);
 }
 
 inline void ArrayDataInformation::setChildWidgetData(uint index, QWidget* w) const
 {
-    if (Q_UNLIKELY(!mData))
-        return;
     mData->setChildWidgetData(index, w);
 }
 
+inline QString ArrayDataInformation::childTypeName(uint index) const
+{
+    return mData->dataAt(index, DataInformation::ColumnType, Qt::DisplayRole).toString();
+}
+
+inline QScriptValue ArrayDataInformation::lengthFunction() const
+{
+    return mLengthFunction;
+}
+
+inline void ArrayDataInformation::setLengthFunction(QScriptValue newFunc)
+{
+    if (!newFunc.isFunction())
+        logError() << "New length function is not a function. It was: " << newFunc.toString();
+    else
+        mLengthFunction = newFunc;
+}
+
 #endif /* ARRAYDATAINFORMATION_H_ */
