@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2011                                               *
+ *   copyright (C) 2003-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -34,7 +34,7 @@ public:
     UMLClassifierListItem(UMLObject *parent,
                           const QString& name,
                           Uml::IDType id = Uml::id_None);
-    UMLClassifierListItem(UMLObject *parent);
+    explicit UMLClassifierListItem(UMLObject *parent);
     virtual ~UMLClassifierListItem();
 
     virtual void setType(UMLObject *type);
