@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2008                                               *
+ *   copyright (C) 2004-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -24,7 +24,7 @@ public:
     /**
      * Constructor
      */
-    JavaCodeClassFieldDeclarationBlock ( CodeClassField * parent );
+    explicit JavaCodeClassFieldDeclarationBlock ( CodeClassField * parent );
 
     /**
      * Empty Destructor
