@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2011                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -39,7 +39,7 @@ public:
                        Uml::IDType id = Uml::id_None,
                        Uml::Visibility s = Uml::Visibility::Private,
                        UMLObject *type = 0, const QString& iv = QString());
-    UMLEntityAttribute(UMLObject* parent);
+    explicit UMLEntityAttribute(UMLObject* parent);
     virtual ~UMLEntityAttribute();
 
     bool operator==(const UMLEntityAttribute& rhs) const;
