@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2004-2011                                               *
+ *   copyright (C) 2004-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -26,12 +26,10 @@ class ToolBarStateOther : public ToolBarStatePool
 {
     Q_OBJECT
 public:
-
-    ToolBarStateOther(UMLScene *umlScene);
+    explicit ToolBarStateOther(UMLScene *umlScene);
     virtual ~ToolBarStateOther();
 
 private:
-
     virtual void setCurrentElement();
 
     virtual void mouseReleaseEmpty();
