@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -86,7 +86,7 @@ class UMLScene : public QGraphicsScene
 public:
     friend class UMLViewImageExporterModel;
 
-    UMLScene(UMLFolder *parentFolder, UMLView *view=0);
+    explicit UMLScene(UMLFolder *parentFolder, UMLView *view = 0);
     virtual ~UMLScene();
 
     UMLView* activeView() const;
@@ -126,8 +126,6 @@ public:
     const QColor& gridDotColor() const;
     void setGridDotColor(const QColor& color);
 
-    void setSize(UMLSceneValue width, UMLSceneValue height);
-
     bool snapToGrid() const;
     void setSnapToGrid(bool bSnap);
 
