@@ -72,7 +72,7 @@ public:
     virtual UMLClassifier* seqNumAndOp(QString& seqNum, QString& op);
     virtual void setSeqNumAndOp(const QString &seqNum, const QString &op);
 
-    virtual void constrainTextPos(int &textX, int &textY, int textWidth, int textHeight,
+    virtual void constrainTextPos(UMLSceneValue &textX, UMLSceneValue &textY, UMLSceneValue textWidth, UMLSceneValue textHeight,
                                   Uml::TextRole tr);
 
     //---------- End LinkWidget Interface methods implemementation.
@@ -85,7 +85,7 @@ public:
         return m_sequenceMessageType;
     }
 
-    bool contains(ObjectWidget * w);
+    bool hasObjectWidget(ObjectWidget * w);
 
     ObjectWidget* objectWidget(Uml::Role_Type role);
     void setObjectWidget(ObjectWidget * ow, Uml::Role_Type role) ;
@@ -119,7 +119,7 @@ public:
     void calculateDimensionsLost();
     void calculateDimensionsFound();
 
-    void paint(QPainter& p, int offsetX, int offsetY);
+    void draw(QPainter& p, int offsetX, int offsetY);
 
     void setTextPosition();
 
@@ -130,7 +130,7 @@ public:
     int getMinY();
     int getMaxY();
 
-    int onWidget(const QPoint & p);
+    UMLSceneValue onWidget(const UMLScenePoint & p);
 
     virtual void saveToXMI(QDomDocument & qDoc, QDomElement & qElement);
     virtual bool loadFromXMI(QDomElement & qElement);
@@ -173,7 +173,7 @@ protected:
     Uml::Sequence_Message_Type m_sequenceMessageType;
 
 private:
-    void moveEvent(QMoveEvent *m);
+    void moveEvent(QGraphicsSceneMouseEvent *m);
     void resizeEvent(QResizeEvent *re);
 
     void init();
