@@ -4,17 +4,13 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2011                                               *
+ *   copyright (C) 2003-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "nodewidget.h"
 
-// qt/kde includes
-#include <QtGui/QPainter>
-#include <QtGui/QPolygon>
-
 // app includes
 #include "debug_utils.h"
 #include "node.h"
@@ -22,6 +18,12 @@
 #include "umldoc.h"
 #include "umlview.h"
 
+// qt includes
+#include <QPainter>
+#include <QPolygon>
+
+DEBUG_REGISTER_DISABLED(NodeWidget)
+
 NodeWidget::NodeWidget(UMLScene * scene, UMLNode *n )
   : UMLWidget(scene, WidgetBase::wt_Node, n)
 {
@@ -33,13 +35,13 @@ NodeWidget::~NodeWidget()
 {
 }
 
-void NodeWidget::paint(QPainter & p, int offsetX, int offsetY)
+void NodeWidget::draw(QPainter & p, int offsetX, int offsetY)
 {
     setPenFromSettings(p);
     if ( UMLWidget::useFillColor() ) {
         p.setBrush( UMLWidget::fillColor() );
     } else {
-        p.setBrush( m_scene->view()->viewport()->palette().color(QPalette::Background) );
+        p.setBrush( m_scene->activeView()->viewport()->palette().color(QPalette::Background) );
     }
     const int w = width();
     const int h = height();
@@ -68,11 +70,11 @@ void NodeWidget::paint(QPainter & p, int offsetX, int offsetY)
     p.setFont(font);
 
     int lines = 1;
-    if (m_pObject) {
-        QString stereotype = m_pObject->stereotype();
+    if (m_umlObject) {
+        QString stereotype = m_umlObject->stereotype();
         if (!stereotype.isEmpty()) {
             p.drawText(offsetX, bodyOffsetY + (bodyHeight/2) - fontHeight,
-                       bodyWidth, fontHeight, Qt::AlignCenter, m_pObject->stereotype(true));
+                       bodyWidth, fontHeight, Qt::AlignCenter, m_umlObject->stereotype(true));
             lines = 2;
         }
     }
@@ -98,15 +100,15 @@ void NodeWidget::paint(QPainter & p, int offsetX, int offsetY)
 
 UMLSceneSize NodeWidget::minimumSize()
 {
-    if (m_pObject == NULL) {
-        uDebug() << "m_pObject is NULL";
+    if (m_umlObject == NULL) {
+        DEBUG(DBG_SRC) << "m_umlObject is NULL";
         return UMLWidget::minimumSize();
     }
 
     const QFontMetrics &fm = getFontMetrics(FT_BOLD_ITALIC);
     const int fontHeight  = fm.lineSpacing();
 
-    QString name = m_pObject->name();
+    QString name = m_umlObject->name();
     if ( UMLWidget::isInstance() ) {
         name = UMLWidget::instanceName() + " : " + name;
     }
@@ -114,8 +116,8 @@ UMLSceneSize NodeWidget::minimumSize()
     int width = fm.width(name);
 
     int tempWidth = 0;
-    if (!m_pObject->stereotype().isEmpty()) {
-        tempWidth = fm.width(m_pObject->stereotype(true));
+    if (!m_umlObject->stereotype().isEmpty()) {
+        tempWidth = fm.width(m_umlObject->stereotype(true));
     }
     if (tempWidth > width)
         width = tempWidth;
