@@ -23,13 +23,14 @@
 #include <klocale.h>
 
 // qt includes
-#include <QMouseEvent>
 #include <QPainter>
 
 #define PIN_MARGIN 5
 #define PIN_WIDTH 1
 #define PIN_HEIGHT 1
 
+DEBUG_REGISTER_DISABLED(PinWidget)
+
 /**
  * Creates a Pin widget.
  *
@@ -44,8 +45,8 @@ PinWidget::PinWidget(UMLScene* scene, UMLWidget* a, Uml::IDType id)
     m_ignoreSnapToGrid = true;
     m_ignoreSnapComponentSizeToGrid = true;
     m_resizable = false;
-    setMinimumSize(10,10);
-    setMaximumSize(10,10);
+    setMinimumSize(UMLSceneSize(10,10));
+    setMaximumSize(UMLSceneSize(10,10));
     setSize(10,10);
     m_nY = y() < getMinY() ? getMinY() : y();
 
@@ -68,7 +69,7 @@ PinWidget::~PinWidget()
 /**
  * Overrides the standard paint event.
  */
-void PinWidget::paint(QPainter & p, int offsetX, int offsetY)
+void PinWidget::draw(QPainter & p, int offsetX, int offsetY)
 {
     int w = 10;
     int h = 10;
@@ -139,7 +140,7 @@ void PinWidget::paint(QPainter & p, int offsetX, int offsetY)
     setZ(20);
     setPenFromSettings(p);
     m_pName->setVisible(( m_pName->text().length() > 0 ));
-    m_pName->updateComponentSize();
+    m_pName->updateGeometry();
     if(m_selected)
          drawSelected(&p, offsetX, offsetY);
 }
@@ -150,7 +151,7 @@ void PinWidget::paint(QPainter & p, int offsetX, int offsetY)
 void PinWidget::setName(const QString &strName)
 {
     m_Text = strName;
-    updateComponentSize();
+    updateGeometry();
     m_pName->setText(m_Text);
 }
 
@@ -171,7 +172,7 @@ int PinWidget::getMinY()
 /**
  * Overrides mouseMoveEvent.
  */
-void PinWidget::mouseMoveEvent(QMouseEvent* me)
+void PinWidget::mouseMoveEvent(QGraphicsSceneMouseEvent* me)
 {
     UMLWidget::mouseMoveEvent(me);
     int diffX = m_oldX - x();
@@ -231,7 +232,7 @@ bool PinWidget::loadFromXMI(QDomElement& qElement)
 
     UMLWidget *pWA = m_scene -> findWidget( aId );
     if (pWA == NULL) {
-        uDebug() << "role A object " << ID2STR(aId) << " not found";
+        DEBUG(DBG_SRC) << "role A object " << ID2STR(aId) << " not found";
         return false;
     }
 
