@@ -25,7 +25,7 @@
 #include <kinputdialog.h>
 
 // qt includes
-#include <QtCore/QPointer>
+#include <QPointer>
 
 /**
  * Creates a State widget.
@@ -53,7 +53,7 @@ StateWidget::~StateWidget()
 /**
  * Overrides the standard paint event.
  */
-void StateWidget::paint(QPainter & p, int offsetX, int offsetY)
+void StateWidget::draw(QPainter & p, int offsetX, int offsetY)
 {
     setPenFromSettings(p);
     const int w = width();
@@ -326,7 +326,7 @@ void StateWidget::setStateType(StateType stateType)
 bool StateWidget::addActivity(const QString &activity)
 {
     m_Activities.append( activity );
-    updateComponentSize();
+    updateGeometry();
     return true;
 }
 
@@ -337,7 +337,7 @@ bool StateWidget::removeActivity(const QString &activity)
 {
     if( m_Activities.removeAll( activity ) == 0 )
         return false;
-    updateComponentSize();
+    updateGeometry();
     return true;
 }
 
@@ -359,7 +359,7 @@ bool StateWidget::renameActivity(const QString &activity, const QString &newName
 void StateWidget::setActivities(const QStringList &list)
 {
     m_Activities = list;
-    updateComponentSize();
+    updateGeometry();
 }
 
 /**
@@ -384,7 +384,7 @@ bool StateWidget::drawVertical() const
 void StateWidget::setDrawVertical(bool to)
 {
     m_drawVertical = to;
-    updateComponentSize();
+    updateGeometry();
     UMLWidget::adjustAssocs( x(), y() );
 }
 
@@ -395,7 +395,7 @@ void StateWidget::showPropertiesDialog()
 {
     umlScene()->updateDocumentation(false);
 
-    QPointer<StateDialog> dialog = new StateDialog(m_scene->view(), this);
+    QPointer<StateDialog> dialog = new StateDialog(m_scene->activeView(), this);
     if (dialog->exec() && dialog->getChangesMade()) {
         umlScene()->showDocumentation(this, true);
         UMLApp::app()->document()->setModified(true);
